
# 0.5.2 (May 2023)

- Remove numpy.bool alias ([#143](https://github.com/ome/omero-cli-zarr/pull/143))

# 0.5.1 (November 2022)

- Fix axes "units" to "unit" ([#131](https://github.com/ome/omero-cli-zarr/pull/131))
